@@ -5,10 +5,8 @@ aembit_nat_output_chain_name=aembit_nat_output_chain
 aembit_nat_prerouting_chain_name=aembit_nat_prerouting_chain
 aembit_filter_input_chain_name=aembit_filter_input_chain
 
-aembit_group_id=$(id --group aembit_agent_proxy)
-agent_proxy_port=38080
-agent_dns_port=8053
-container_cidr=$AEMBIT_DOCKER_CONTAINER_CIDR
+aembit_agent_proxy_user_name=aembit_agent_proxy
+aembit_group_id=$(id --group "${aembit_agent_proxy_user_name}")
 azure_platform_resources_ip=168.63.129.16
 
 update-alternatives --set iptables /usr/sbin/iptables-legacy
