@@ -5,12 +5,13 @@ aembit_nat_output_chain_name=aembit_nat_output_chain
 aembit_nat_prerouting_chain_name=aembit_nat_prerouting_chain
 aembit_filter_input_chain_name=aembit_filter_input_chain
 
-aembit_group_id=$(id --group aembit_agent_proxy)
+aembit_agent_proxy_user_name=aembit_agent_proxy
+aembit_group_id=$(id --group "${aembit_agent_proxy_user_name}")
 agent_proxy_port=38080
 agent_dns_port=8053
 container_cidr=$AEMBIT_DOCKER_CONTAINER_CIDR
 # https://learn.microsoft.com/en-us/azure/virtual-network/what-is-ip-address-168-63-129-16
-azure_platform_resources_ip=168.63.129.16
+azure_platform_resources_ip="168.63.129.16"
 
 update-alternatives --set iptables /usr/sbin/iptables-legacy
 update-alternatives --set ip6tables /usr/sbin/ip6tables-legacy
@@ -68,12 +69,16 @@ iptables -t raw -A OUTPUT -j "${aembit_raw_output_chain_name}"
 # Create chain
 iptables -t nat -N "${aembit_nat_output_chain_name}"
 
-# Ignore (return to the main chain) all packets from our agent proxy
+# Ignore all packets from the Agent Proxy
 iptables -t nat -A "${aembit_nat_output_chain_name}" -m owner --gid-owner "${aembit_group_id}" -j RETURN
 
 # Ignore TCP loopback
 iptables -t nat -A "${aembit_nat_output_chain_name}" -p tcp -o lo -j RETURN
 
+# Ignore outbound traffic to the Azure communication channel.
+# See https://learn.microsoft.com/en-us/azure/virtual-network/what-is-ip-address-168-63-129-16.
+iptables -t nat -A "${aembit_nat_output_chain_name}" -p tcp --destination "${azure_platform_resources_ip}" -j RETURN
+
 # Redirect all new TCP connections to the Agent Proxy.
 # We use the "--syn" flag to forward new connections only, since,
 # prior to adding NAT rules, conntrack is not loaded. Once we add NAT rules,
@@ -99,7 +104,7 @@ iptables -t nat -N "${aembit_nat_prerouting_chain_name}"
 # Container traffic hits the NAT table's PREROUTING chain and can be redirected from there to the Agent Proxy.
 # If the containers CIDR block was specified, we create a chain and accompanying rule to do that.
 if [ -n "$container_cidr" ]; then
-    iptables -t nat -A "${aembit_nat_prerouting_chain_name}" -p tcp --syn -s $container_cidr -j REDIRECT --to-port $agent_proxy_port
+    iptables -t nat -A "${aembit_nat_prerouting_chain_name}" -p tcp --syn -s "${container_cidr}" -j REDIRECT --to-port $agent_proxy_port
 fi
 
 # Add chain
@@ -115,7 +120,7 @@ iptables -t filter -A "${aembit_filter_input_chain_name}" -p tcp --dport "${agen
 
 # Allow traffic from local containers to be sent to the Agent proxy traffic port.
 if [ -n "$container_cidr" ]; then
-    iptables -t filter -A "${aembit_filter_input_chain_name}" -p tcp -s  $container_cidr --dport "${agent_proxy_port}" -j ACCEPT
+    iptables -t filter -A "${aembit_filter_input_chain_name}" -p tcp -s  "${container_cidr}" --dport "${agent_proxy_port}" -j ACCEPT
 fi
 
 # Disallow the rest of the traffic (coming from external interfaces) to be sent to the Agent Proxy traffic port.
@@ -123,13 +128,3 @@ iptables -t filter -A "${aembit_filter_input_chain_name}" -p tcp --dport "${agen
 
 # Add chain
 iptables -t filter -A INPUT -j "${aembit_filter_input_chain_name}"
-
-# ------ Non custom chains ------
-
-# https://learn.microsoft.com/en-us/azure/virtual-network/what-is-ip-address-168-63-129-16
-# "IP address 168.63.129.16 is a virtual public IP address that is used to facilitate a communication channel to Azure platform resources. "
-# There are several iptable rules in the security table preinstalled on Azure's Linux VMs that restrict
-# who can communicate with this IP.
-# This rule is to allow us to communicate with it.
-
-iptables -t security -I OUTPUT -p tcp -d "${azure_platform_resources_ip}" -m owner --gid-owner "${aembit_group_id}" -j ACCEPT
